# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

from winrt.windows.globalization.phonenumberformatting import PhoneNumberFormat, PhoneNumberMatchResult, PhoneNumberParseResult, PredictedPhoneNumberKind

Self = typing.TypeVar('Self')

@typing.final
class PhoneNumberFormatter_Static(winrt._winrt.IInspectable_Static):
    # System.Int32 Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::GetCountryCodeForRegion(System.String)
    def get_country_code_for_region(cls, region_code: str, /) -> winrt.system.Int32: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::GetNationalDirectDialingPrefixForRegion(System.String,System.Boolean)
    def get_national_direct_dialing_prefix_for_region(cls, region_code: str, strip_non_digit: bool, /) -> str: ...
    # System.Void Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::TryCreate(System.String,Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter&)
    def try_create(cls, region_code: str, /) -> PhoneNumberFormatter: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::WrapWithLeftToRightMarkers(System.String)
    def wrap_with_left_to_right_markers(cls, number: str, /) -> str: ...

@typing.final
class PhoneNumberFormatter(winrt.system.Object, metaclass=PhoneNumberFormatter_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::Format(Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo)
    def format(self, number: PhoneNumberInfo, /) -> str: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::FormatPartialString(System.String)
    def format_partial_string(self, number: str, /) -> str: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::FormatString(System.String)
    def format_string(self, number: str, /) -> str: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::FormatStringWithLeftToRightMarkers(System.String)
    def format_string_with_left_to_right_markers(self, number: str, /) -> str: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter::Format(Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo,Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormat)
    def format_with_output_format(self, number: PhoneNumberInfo, number_format: PhoneNumberFormat, /) -> str: ...

@typing.final
class PhoneNumberInfo_Static(winrt._winrt.IInspectable_Static):
    # Windows.Globalization.PhoneNumberFormatting.PhoneNumberParseResult Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::TryParse(System.String,Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo&)
    def try_parse(cls, input: str, /) -> typing.Tuple[PhoneNumberParseResult, PhoneNumberInfo]: ...
    # Windows.Globalization.PhoneNumberFormatting.PhoneNumberParseResult Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::TryParse(System.String,System.String,Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo&)
    def try_parse_with_region(cls, input: str, region_code: str, /) -> typing.Tuple[PhoneNumberParseResult, PhoneNumberInfo]: ...

@typing.final
class PhoneNumberInfo(winrt.system.Object, windows_foundation.IStringable, metaclass=PhoneNumberInfo_Static):
    def __str__(self) -> str: ...
    def __new__(cls: typing.Type[Self], number: str) -> Self: ...
    # Windows.Globalization.PhoneNumberFormatting.PhoneNumberMatchResult Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::CheckNumberMatch(Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo)
    def check_number_match(self, other_number: PhoneNumberInfo, /) -> PhoneNumberMatchResult: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::GetGeographicRegionCode()
    def get_geographic_region_code(self) -> str: ...
    # System.Int32 Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::GetLengthOfGeographicalAreaCode()
    def get_length_of_geographical_area_code(self) -> winrt.system.Int32: ...
    # System.Int32 Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::GetLengthOfNationalDestinationCode()
    def get_length_of_national_destination_code(self) -> winrt.system.Int32: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::GetNationalSignificantNumber()
    def get_national_significant_number(self) -> str: ...
    # Windows.Globalization.PhoneNumberFormatting.PredictedPhoneNumberKind Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::PredictNumberKind()
    def predict_number_kind(self) -> PredictedPhoneNumberKind: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::ToString()
    def to_string(self) -> str: ...
    # System.Int32 Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::get_CountryCode()
    @_property
    def country_code(self) -> winrt.system.Int32: ...
    # System.String Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo::get_PhoneNumber()
    @_property
    def phone_number(self) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import enum

import winrt.system
from winrt._winrt_windows_globalization_phonenumberformatting import (
    PhoneNumberFormatter,
    PhoneNumberInfo,
)

__all__ = [
    "PhoneNumberFormat",
    "PhoneNumberMatchResult",
    "PhoneNumberParseResult",
    "PredictedPhoneNumberKind",
    "PhoneNumberFormatter",
    "PhoneNumberInfo",
]

class PhoneNumberFormat(enum.IntEnum):
    E164 = 0
    INTERNATIONAL = 1
    NATIONAL = 2
    RFC3966 = 3

class PhoneNumberMatchResult(enum.IntEnum):
    NO_MATCH = 0
    SHORT_NATIONAL_SIGNIFICANT_NUMBER_MATCH = 1
    NATIONAL_SIGNIFICANT_NUMBER_MATCH = 2
    EXACT_MATCH = 3

class PhoneNumberParseResult(enum.IntEnum):
    VALID = 0
    NOT_A_NUMBER = 1
    INVALID_COUNTRY_CODE = 2
    TOO_SHORT = 3
    TOO_LONG = 4

class PredictedPhoneNumberKind(enum.IntEnum):
    FIXED_LINE = 0
    MOBILE = 1
    FIXED_LINE_OR_MOBILE = 2
    TOLL_FREE = 3
    PREMIUM_RATE = 4
    SHARED_COST = 5
    VOIP = 6
    PERSONAL_NUMBER = 7
    PAGER = 8
    UNIVERSAL_ACCOUNT_NUMBER = 9
    VOICEMAIL = 10
    UNKNOWN = 11

